@@ -13,35 +13,28 @@ use warnings;
 
 package Games::Pandemic::Utils;
 BEGIN {
-  $Games::Pandemic::Utils::VERSION = '1.111010';
+  $Games::Pandemic::Utils::VERSION = '1.111030';
 }
 # ABSTRACT: various utilities for pandemic
 
 use Devel::CheckOS        qw{ os_is };
-use Encode;
-use File::Basename        qw{ fileparse };
 use File::HomeDir         qw{ my_data };
+use File::ShareDir::PathClass;
 use File::Spec::Functions qw{ catdir updir };
 use FindBin               qw{ $Bin };
-use Locale::TextDomain    'Games-Pandemic';
-use Module::Util          qw{ find_installed };
 use Moose;
 use Readonly;
  
 extends 'Exporter';
-our @EXPORT = qw{ $CONFIGDIR $SHAREDIR T debug };
+our @EXPORT = qw{ $CONFIGDIR $SHAREDIR debug };
 
 Readonly our $CONFIGDIR => _find_config_dir();
-Readonly our $SHAREDIR  => _find_share_dir();
+our $SHAREDIR = File::ShareDir::PathClass->dist_dir("Games-Pandemic");
 
 
 # -- public subs
 
 
-sub T { return decode('utf8', __($_[0])); }
-
-
-
 my $debug = -d catdir( $Bin, updir(), '.git' );
 sub debug {
     return unless $debug;
@@ -61,18 +54,6 @@ sub _find_config_dir {
     return catdir( my_data(), $subdir, 'Games-Pandemic' );
 }
 
-
-#
-# my $path = _find_share_dir();
-#
-# return the absolute path where all resources will be placed.
-#
-sub _find_share_dir {
-    my $path = find_installed(__PACKAGE__);
-    my ($undef, $dirname) = fileparse($path);
-    return catdir($dirname, 'share');
-}
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -87,7 +68,7 @@ Games::Pandemic::Utils - various utilities for pandemic
 
 =head1 VERSION
 
-version 1.111010
+version 1.111030
 
 =head1 DESCRIPTION
 
@@ -96,12 +77,6 @@ various occasions throughout the code.
 
 =head1 METHODS
 
-=head2 my $locstr = T( $string )
-
-Performs a call to C<gettext> on C<$string>, convert it from utf8 and
-return the result. Note that i18n is using C<Locale::TextDomain>
-underneath, so refer to this module for more information.
-
 =head2 debug( @stuff );
 
 Output C<@stuff> on stderr if we're in a local git checkout. Do nothing
